@@ -1,12 +1,7 @@
 package NanoMsg::Raw;
-BEGIN {
-  $NanoMsg::Raw::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $NanoMsg::Raw::VERSION = '0.02';
-}
+our $AUTHORITY = 'cpan:FLORA';
 # ABSTRACT: Low-level interface to the nanomsg scalability protocols library
-
+$NanoMsg::Raw::VERSION = '0.03';
 use strict;
 use warnings;
 use XSLoader;
@@ -42,7 +37,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -50,14 +45,16 @@ NanoMsg::Raw - Low-level interface to the nanomsg scalability protocols library
 
 =head1 SYNOPSIS
 
+    use Test::More;
     use NanoMsg::Raw;
 
     my $sb = nn_socket(AF_SP, NN_PAIR);
     nn_bind($sb, 'inproc://foo');
-    nn_send($sb, 'bar');
 
     my $sc = nn_socket(AF_SP, NN_PAIR);
     nn_connect($sc, 'inproc://foo');
+
+    nn_send($sb, 'bar');
     nn_recv($sc, my $buf);
     is $buf, 'bar';
 
@@ -93,7 +90,7 @@ simple many-to-many communication
 
 C<REQREP>
 
-allows to build clusters of stateless services to process user requests
+allows one to build clusters of stateless services to process user requests
 
 =item *
 
@@ -112,7 +109,7 @@ destinations
 
 C<SURVEY>
 
-allows to query state of multiple applications in a single go
+allows one to query state of multiple applications in a single go
 
 =back
 
@@ -650,7 +647,7 @@ The provided socket is invalid.
 
 C<EINVAL>
 
-The how parameter doesn’t correspond to an active endpoint.
+The how parameter doesn't correspond to an active endpoint.
 
 =item *
 
@@ -810,7 +807,7 @@ between several states.
 
 C<EAGAIN>
 
-Non-blocking mode was requested and there’s no message to receive at the moment.
+Non-blocking mode was requested and there's no message to receive at the moment.
 
 =item *
 
@@ -1024,7 +1021,7 @@ C<nn_strerror(nn_errno)>.
 Starts a device to forward messages between two sockets. If both sockets are
 valid, the C<nn_device> function loops and sends and messages received from
 C<$s1> to C<$s2> and vice versa. If only one socket is valid and the other is
-C<undef>, C<nn_device> works in a loopback mode — it loops and sends any
+C<undef>, C<nn_device> works in a loopback mode - it loops and sends any
 messages received from the socket back to itself.
 
 The function loops until it hits an error. In such case it returns C<undef> and
@@ -1042,8 +1039,8 @@ One of the provided sockets is invalid.
 
 C<EINVAL>
 
-Either one of the socket is not an C<AF_SP_RAW> socket; or the two sockets don’t
-belong to the same protocol; or the directionality of the sockets doesn’t fit
+Either one of the socket is not an C<AF_SP_RAW> socket; or the two sockets don't
+belong to the same protocol; or the directionality of the sockets doesn't fit
 (e.g. attempt to join two SINK sockets to form a device).
 
 =item *
@@ -1080,7 +1077,7 @@ The C<nn_term> function itself is non-blocking.
 
 =head1 WARNING
 
-B<nanomsg, the c library this module is based on, is still in alpha stage!>
+B<nanomsg, the c library this module is based on, is still in beta stage!>
 
 =head1 Protocols
 
@@ -1093,7 +1090,7 @@ can be split into two applications (accounting vs. HR) that are run on two
 separate servers. These applications can then communicate via PAIR sockets.
 
 The downside of this protocol is that its scaling properties are very
-limited. Splitting the application into two pieces allows to scale to two
+limited. Splitting the application into two pieces allows one to scale to two
 servers. To add the third server to the cluster, application has to be split
 once more, say be separating HR functionality into hiring module and salary
 computation module. Whenever possible, try to use one of the more scalable
@@ -1109,7 +1106,7 @@ C<NN_PAIR>
 
 Socket for communication with exactly one peer. Each party can send messages at
 any time. If the peer is not available or send buffer is full subsequent calls
-to C<nn_send> will block until it’s possible to send the message.
+to C<nn_send> will block until it's possible to send the message.
 
 =back
 
@@ -1176,7 +1173,7 @@ C<NN_SUB>
 Receives messages from the publisher. Only messages that the socket is
 subscribed to are received. When the socket is created there are no
 subscriptions and thus no messages will be received. Send operation is not
-defined on this socket. The socket can be connected to at most one peer.
+defined on this socket.
 
 =back
 
@@ -1202,7 +1199,7 @@ option is string.
 
 =head2 Survey protocol
 
-Allows to broadcast a survey to multiple locations and gather the responses.
+allows one to broadcast a survey to multiple locations and gather the responses.
 
 =head3 Socket Types
 
@@ -1307,7 +1304,7 @@ There are no options defined at the moment.
 
 =head2 In-process transport
 
-The in-process transport allows to send messages between threads or modules inside a
+The in-process transport allows one to send messages between threads or modules inside a
 process. In-process address is an arbitrary case-sensitive string preceded by
 C<inproc://> protocol specifier. All in-process addresses are visible from any
 module within the process. They are not visible from outside of the process.
@@ -1316,7 +1313,7 @@ The overall buffer size for an inproc connection is determined by the
 C<NN_RCVBUF> socket option on the receiving end of the connection. The
 C<NN_SNDBUF> socket option is ignored. In addition to the buffer, one message of
 arbitrary size will fit into the buffer. That way, even messages larger than the
-buffer can be transfered via inproc connection.
+buffer can be transferred via inproc connection.
 
 This transport's ID is C<NN_INPROC>.
 
@@ -1421,7 +1418,7 @@ This transport's ID is C<NN_TCP>.
 
 C<NN_TCP_NODELAY>
 
-This option, when set to 1, disables Nagle’s algorithm. It also disables
+This option, when set to 1, disables Nagle's algorithm. It also disables
 delaying of TCP acknowledgments. Using this option improves latency at the
 expense of throughput. Type of this option is int. The default value is 0.
 
@@ -1557,7 +1554,7 @@ Boris Zentner <bzm@2bz.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Florian Ragwitz.
+This software is Copyright (c) 2015 by Florian Ragwitz.
 
 This is free software, licensed under:
 
