@@ -2,14 +2,9 @@ use strict;
 use warnings;
 
 package NanoMsg::Raw::Message;
-BEGIN {
-  $NanoMsg::Raw::Message::AUTHORITY = 'cpan:FLORA';
-}
-{
-  $NanoMsg::Raw::Message::VERSION = '0.02';
-}
+our $AUTHORITY = 'cpan:FLORA';
 # ABSTRACT: Message buffer for NanoMsg::Raw
-
+$NanoMsg::Raw::Message::VERSION = '0.03';
 use overload '""' => sub { ${ $_[0] } }, fallback => 1;
 
 
@@ -19,7 +14,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -85,7 +80,7 @@ Boris Zentner <bzm@2bz.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Florian Ragwitz.
+This software is Copyright (c) 2015 by Florian Ragwitz.
 
 This is free software, licensed under:
 
